          * [Managing Fact Sheet Subscriptions (GraphQL)](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-subscriptions)
          * [Retrieving Event Logs for a Fact Sheet (GraphQL)](https://help.sap.com/docs/leanix/ea/retrieving-event-logs-for-fact-sheet)
      * [Integration API](https://help.sap.com/docs/leanix/ea/integration-api)
        * [Getting Started with the Integration API](https://help.sap.com/docs/leanix/ea/getting-started-with-integration-api)
        * [Inbound Processors](https://help.sap.com/docs/leanix/ea/inbound-processors)
        * [Outbound Processors](https://help.sap.com/docs/leanix/ea/outbound-processors)
        * [Advanced Use Cases for the Integration API](https://help.sap.com/docs/leanix/ea/advanced-use-cases-for-integration-api)
        * [Integration REST API](https://help.sap.com/docs/leanix/ea/integration-rest-api)
        * [Initiating Integration API Runs with Python](https://help.sap.com/docs/leanix/ea/initiating-integration-api-runs-with-python)
        * [Configuring Automated Nightly Runs for Inbound Processors](https://help.sap.com/docs/leanix/ea/configuring-automated-nightly-runs-for-inbound-processors)
        * [Best Practices for the Integration API](https://help.sap.com/docs/leanix/ea/best-practices-for-integration-api)
        * [Integration API Tutorials](https://help.sap.com/docs/leanix/ea/integration-api-tutorials)
          * [Importing and Updating Fact Sheets](https://help.sap.com/docs/leanix/ea/importing-and-updating-fact-sheets)
          * [Calculating Scores from Numeric Fields and Updating Custom Fact Sheet Fields](https://help.sap.com/docs/leanix/ea/calculating-scores-from-numeric-fields-and-updating-custom-fact-sheet-fields)
          * [Importing Resources to Fact Sheets](https://help.sap.com/docs/leanix/ea/importing-resources-to-fact-sheets)
      * [Webhooks](https://help.sap.com/docs/leanix/ea/webhooks)
        * [PUSH Webhooks](https://help.sap.com/docs/leanix/ea/push-webhooks)
        * [PULL Webhooks](https://help.sap.com/docs/leanix/ea/pull-webhooks)
        * [Webhook Events](https://help.sap.com/docs/leanix/ea/webhook-events)
        * [Webhook Payloads](https://help.sap.com/docs/leanix/ea/webhook-payloads)
      * [Rate Limiting](https://help.sap.com/docs/leanix/ea/rate-limiting)
      * [Response Status Codes](https://help.sap.com/docs/leanix/ea/response-status-codes)
      * [API Updates](https://help.sap.com/docs/leanix/ea/api-updates)
        * [Poll API Deprecation: Transition to the New Survey API](https://help.sap.com/docs/leanix/ea/poll-api-updates-transition-to-new-survey-api)
        * [GraphQL API: Error Handling for Multiple Mutations Sent in a Single Request (July 28, 2025)](https://help.sap.com/docs/leanix/ea/api-updates-graphql-error-handling)
        * [Self-Built Software Discovery API: Asynchronous Processing of SBOM File Ingestions (April 7, 2025)](https://help.sap.com/docs/leanix/ea/api-updates-sbom-async-processing)
        * [GraphQL API Changes (January 15, 2025)](https://help.sap.com/docs/leanix/ea/api-updates-graphql-api-changes)
    * [Reporting Framework and CLI](https://help.sap.com/docs/leanix/ea/reporting-framework-and-cli)
  * [Additional Resources](https://help.sap.com/docs/leanix/ea/additional-resources)
    * [Data Privacy Statement: SAP LeanIX Workspace](https://help.sap.com/docs/leanix/ea/data-privacy-statement-sap-leanix-workspace)
    * [Cookies and Local Storage Policy: SAP LeanIX Workspace](https://help.sap.com/docs/leanix/ea/cookies-and-local-storage-policy-sap-leanix-workspace)
    * [SAP LeanIX Applications Terms and Conditions (Microsoft Teams)](https://help.sap.com/docs/leanix/ea/sap-leanix-applications-terms-and-conditions-microsoft-teams)
    * [Geo-Blocking](https://help.sap.com/docs/leanix/ea/geo-blocking)
    * [Data Quality Control Mechanisms](https://help.sap.com/docs/leanix/ea/data-quality-control-mechanisms)
    * [Welcome to the New Home of SAP LeanIX Documentation](https://help.sap.com/docs/leanix/ea/documentation-on-sap-help-portal)
